==> haskell-nanospec-0.2.2-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nanospec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 nanospec
version:              0.2.2
visibility:           public
id:                   nanospec-0.2.2-6ARXtYEEHxoIR6d5rHfTLr
key:                  nanospec-0.2.2-6ARXtYEEHxoIR6d5rHfTLr
license:              MIT
copyright:            (c) 2012-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/nanospec#readme
synopsis:             A lightweight implementation of a subset of Hspec'\''s API
description:
    A lightweight implementation of a subset of Hspec'\''s API with minimal dependencies.

category:             Testing
abi:                  e1aaa70b8b0a4436894fab04442e4513
exposed-modules:      Test.Hspec
hidden-modules:       Paths_nanospec
import-dirs:          /usr/lib/ghc-8.10.1/site-local/nanospec-0.2.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/nanospec-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/nanospec-0.2.2
hs-libraries:         HSnanospec-0.2.2-6ARXtYEEHxoIR6d5rHfTLr
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-nanospec/html/nanospec.haddock
haddock-html:         /usr/share/doc/haskell-nanospec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nanospec-0.2.2-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nanospec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 nanospec
version:              0.2.2
visibility:           public
id:                   nanospec-0.2.2-8YZWmbIHziYEugUAvRsuu6
key:                  nanospec-0.2.2-8YZWmbIHziYEugUAvRsuu6
license:              MIT
copyright:            (c) 2012-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/nanospec#readme
synopsis:             A lightweight implementation of a subset of Hspec'\''s API
description:
    A lightweight implementation of a subset of Hspec'\''s API with minimal dependencies.

category:             Testing
abi:                  8a5e2f0130af68eca9e4e4409c22e424
exposed-modules:      Test.Hspec
hidden-modules:       Paths_nanospec
import-dirs:          /usr/lib/ghc-8.10.1/site-local/nanospec-0.2.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/nanospec-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/nanospec-0.2.2
hs-libraries:         HSnanospec-0.2.2-8YZWmbIHziYEugUAvRsuu6
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-nanospec/html/nanospec.haddock
haddock-html:         /usr/share/doc/haskell-nanospec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
